@@ -4,8 +4,9 @@
 
 """
 
-__version__ = "1.0.17"
+__version__ = "1.0.22"
 
 from binance.client import Client, AsyncClient  # noqa
 from binance.depthcache import DepthCacheManager, OptionsDepthCacheManager, ThreadedDepthCacheManager  # noqa
-from binance.streams import BinanceSocketManager, ThreadedWebsocketManager  # noqa
+from binance.streams import BinanceSocketManager, ThreadedWebsocketManager, BinanceSocketType  # noqa
+from binance.enums import *  # noqa
\ No newline at end of file
